
from django.test import TestCase

from .decorators import enable


class AfterResponseTest(TestCase):

    def test_execution(self):
        self.executed = False

        @enable
        def func(val):
            self.executed = val

        self.assertFalse(self.executed)
        self.client.get('/')
        self.assertFalse(self.executed)

        func.after_response(True)

        self.assertFalse(self.executed)
        self.client.get('/')
        self.assertTrue(self.executed)




import logging

from django.core.signals import request_finished

from .store import function_queue

logger = logging.getLogger(__name__)


def run_em_all(*args, **kwargs):
    for func, args, kwargs in function_queue:
        try:
            func(*args, **kwargs)
        except Exception as e:
            logger.exception(str(e))
request_finished.connect(run_em_all)




from .store import function_queue

def enable(func):
    def after_response(*args, **kwargs):
        function_queue.append((func, args, kwargs))
    func.after_response = after_response
    return func
